@@ -14,9 +14,9 @@ admin.site.index_title = 'MSA一体化管理后台'  # 首页的标题
 
 class BaseInfoAdmin(admin.ModelAdmin):
     # fields = ('user_name', 'full_name', 'platform', 'platform_uid', 'phone', 'email', 'wechat', 'user_info')
-    fields = ('user_name', 'full_name', 'phone', 'email', 'wechat', 'user_info', 'user_group', 'permission')
-    list_display = ('id', 'user_name', 'full_name', 'phone', 'email', 'wechat', 'user_info', 'user_group', 'permission')
-    search_fields = ('user_name', 'full_name', 'phone', 'user_group')
+    fields = ('user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group', 'permission', 'register_time')
+    list_display = ('id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group', 'permission', 'register_time')
+    search_fields = ('user_name', 'full_name', 'nickname', 'phone', 'user_group__group')
     list_filter = []
 
 
@@ -41,8 +41,8 @@ class DetailInfoAdmin(admin.ModelAdmin):
 
 
 class ExtendFiledAdmin(admin.ModelAdmin):
-    fields = ('field', 'key_name', 'description')
-    list_display = ('field', 'key_name', 'description')
+    fields = ('field', 'field_index', 'description')
+    list_display = ('field', 'field_index', 'description')
 
 
 class AccessLogAdmin(admin.ModelAdmin):
