@@ -14,14 +14,14 @@ from ..validator import GroupValidator
 
 
 class GroupAPIView(APIView):
-    def get(self, request):
-        return model_select(request, Group)
+    def list(self, *args):
+        return util_response(data=list(Group.objects.all().values()))
 
-    def post(self, request):
+    def post(self, request, *args):
         return model_create(request, Group, GroupValidator)
 
-    def put(self, request):
+    def put(self, request, *args):
         return model_update(request, Group)
 
-    def delete(self, request):
-        return model_del(request, Group)
+    def delete(self, request, *args):
+        return model_delete(request, Group)
