@@ -8,8 +8,8 @@
 # 微信登录方法
 from rest_framework.views import APIView
 
-from ..services.wechat_service import WechatService
-from ..utils.custom_response import util_response
+from xj_user.services.wechat_service import WechatService
+from xj_user.utils.custom_response import util_response
 
 
 class WechetLogin(APIView):
