@@ -1,5 +1,5 @@
 from django.db import models
-
+from django.utils import timezone
 
 # Create your models here.
 
@@ -62,10 +62,11 @@ class BaseInfo(models.Model):
     nickname = models.CharField(verbose_name='昵称', max_length=128, blank=True, null=True)
     phone = models.CharField(verbose_name='手机', max_length=128, blank=True, null=True, db_index=True)
     email = models.EmailField(verbose_name='邮箱', blank=True, null=True, db_index=True)
-    wechat = models.CharField(verbose_name='微信号', max_length=128, blank=True, null=True, db_index=True)
+    wechat_openid = models.CharField(verbose_name='微信开放号', max_length=128, blank=True, null=True, db_index=True)
     user_info = models.JSONField(verbose_name='用户信息', blank=True, null=True)
     user_group = models.ForeignKey(Group, verbose_name='用户分组', blank=True, null=True, on_delete=models.DO_NOTHING)
     permission = models.ForeignKey(Permission, verbose_name='用户权限', blank=True, null=True, on_delete=models.DO_NOTHING)
+    register_time = models.DateTimeField(verbose_name='注册时间', default=timezone.now(), )
 
     class Meta:
         db_table = 'user_base_info'
@@ -74,7 +75,7 @@ class BaseInfo(models.Model):
 
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
-        return f"{self.full_name}"
+        return f"{self.user_name}"
 
     def get_group_desc(self):
         return self.user_group.description if self.user_group else ""
@@ -85,7 +86,7 @@ class BaseInfo(models.Model):
 
 # 2、User_Auth 认证表 [1-1]
 class Auth(models.Model):
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, )
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', unique=True, on_delete=models.DO_NOTHING, )
     password = models.CharField(verbose_name='密码', max_length=255, blank=True, null=True, )
     plaintext = models.CharField(verbose_name='PT', max_length=255, blank=True, null=True, )
     salt = models.CharField(verbose_name='盐', max_length=32, blank=True, null=True, )
@@ -106,7 +107,7 @@ class Auth(models.Model):
 
 # 3、User_Detail_Info 详细信息表 [1-1]
 class DetailInfo(models.Model):
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, )
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', unique=True, on_delete=models.DO_NOTHING, )
     real_name = models.CharField(verbose_name='真实姓名', max_length=255, blank=True, null=True, db_index=True, )
     sex = models.CharField(verbose_name='性别', max_length=1, blank=True, null=True, )
     birth = models.DateField(verbose_name='生日', blank=True, null=True, )
@@ -117,21 +118,21 @@ class DetailInfo(models.Model):
     language = models.CharField(verbose_name='语言', max_length=32, blank=True, null=True, )
     region_code = models.BigIntegerField(verbose_name='地区编码', blank=True, null=True, db_index=True, )
     more = models.JSONField(verbose_name='更多信息', max_length=255, blank=True, null=True, )
-    field_1 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_2 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_3 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_4 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_5 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_6 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_7 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_8 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_9 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_10 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_11 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_12 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_13 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_14 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
-    field_15 = models.CharField(verbose_name='信息', max_length=255, blank=True, null=True, )
+    field_1 = models.CharField(verbose_name='字段1', max_length=255, blank=True, null=True, )
+    field_2 = models.CharField(verbose_name='字段2', max_length=255, blank=True, null=True, )
+    field_3 = models.CharField(verbose_name='字段3', max_length=255, blank=True, null=True, )
+    field_4 = models.CharField(verbose_name='字段4', max_length=255, blank=True, null=True, )
+    field_5 = models.CharField(verbose_name='字段5', max_length=255, blank=True, null=True, )
+    field_6 = models.CharField(verbose_name='字段6', max_length=255, blank=True, null=True, )
+    field_7 = models.CharField(verbose_name='字段7', max_length=255, blank=True, null=True, )
+    field_8 = models.CharField(verbose_name='字段8', max_length=255, blank=True, null=True, )
+    field_9 = models.CharField(verbose_name='字段9', max_length=255, blank=True, null=True, )
+    field_10 = models.CharField(verbose_name='字段10', max_length=255, blank=True, null=True, )
+    field_11 = models.CharField(verbose_name='字段11', max_length=255, blank=True, null=True, )
+    field_12 = models.CharField(verbose_name='字段12', max_length=255, blank=True, null=True, )
+    field_13 = models.CharField(verbose_name='字段13', max_length=255, blank=True, null=True, )
+    field_14 = models.CharField(verbose_name='字段14', max_length=255, blank=True, null=True, )
+    field_15 = models.CharField(verbose_name='字段15', max_length=255, blank=True, null=True, )
 
     class Meta:
         db_table = 'user_detail_info'
@@ -143,16 +144,16 @@ class DetailInfo(models.Model):
 
 
 class ExtendFiled(models.Model):
-    field = models.CharField(verbose_name='字段名称', max_length=255, blank=True, null=True, db_index=True, )
-    key_name = models.CharField(verbose_name='标签映射', max_length=255, blank=True, null=True, )
+    field = models.CharField(verbose_name='自定义字段', max_length=255, unique=True, blank=True, null=True, db_index=True, )
+    field_index = models.CharField(verbose_name='映射索引名', max_length=255, unique=True, blank=True, null=True, )
     description = models.CharField(verbose_name='字段描述', max_length=255, blank=True, null=True, )
 
     class Meta:
         db_table = 'user_extend_field'
-        verbose_name_plural = "04. 用户 - 冗余扩展表"
+        verbose_name_plural = "04. 用户 - 扩展字段表"
 
     def __str__(self):
-        return f"{self.key_name}"
+        return f"{self.field}"
 
 
 # 4、*User_Access_Log 访问日志表 [1-N]
