@@ -8,10 +8,10 @@
 """
 from datetime import datetime, timedelta
 
+from django.contrib.auth.hashers import make_password
 import jwt
 import redis
 import requests
-from django.contrib.auth.hashers import make_password
 
 from config.config import Config
 from ..models import BaseInfo, Auth
@@ -24,12 +24,11 @@ class WechatService:
     wx_get_phone_url = "https://api.weixin.qq.com/wxa/business/getuserphonenumber"
 
     def __init__(self):
-        self.config = Config()
-        self.login_param = {'appid': self.config.getRaw("weichaet", 'app_id'), 'secret': self.config.getRaw("weichaet", 'secret'), 'grant_type': 'authorization_code'}
+        self.login_param = {'appid': Config.getIns().get("xj_user", 'app_id'), 'secret': Config.getIns().get("xj_user", 'secret'), 'grant_type': 'authorization_code'}
         self.redis = redis.Redis(
-            host=self.config.getRaw("redis", 'host'),
-            port=self.config.getRaw("redis", 'port'),
-            password=self.config.getRaw("redis", 'password')
+            host=Config.getIns().get("main", 'redis_host'),
+            port=Config.getIns().get("main", 'redis_port'),
+            password=Config.getIns().get("main", 'redis_password')
         )
 
     def get_openid(self, code):
@@ -51,7 +50,7 @@ class WechatService:
         :return:(err,data)
         """
         # code 换取手机号
-        url = self.wx_get_phone_url + "?access_token={}".format(self.get_access_token()['access_token'].decode('utf-8'))
+        url = self.wx_get_phone_url + "?access_token={}".format(self.get_access_token()['access_token'])
         header = {'content-type': 'application/json'}
         response = requests.post(url, json={'code': code}, headers=header).json()
         if not response['errcode'] == 0:
@@ -85,28 +84,27 @@ class WechatService:
     def __set_token(self, user_id, account):
         # 生成过期时间
         expire_timestamp = datetime.utcnow() + timedelta(
-            days=int(self.config.getRaw('jwt', 'EXPIRE_DAY')),
-            seconds=int(self.config.getRaw('jwt', 'EXPIRE_SECOND'))
+            days=int(Config.getIns().get('xj_user', 'EXPIRE_DAY')),
+            seconds=int(Config.getIns().get('xj_user', 'EXPIRE_SECOND'))
         )
         # 返回token
         return jwt.encode(
             payload={'user_id': user_id, 'account': account, "exp": expire_timestamp},
-            key=self.config.getRaw('jwt', 'JWT_SECRET_KEY')
+            key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY')
         )
 
     def get_access_token(self):
         access_token = self.redis.get('access_token')
         if access_token:
             ttl = self.redis.ttl('access_token')
-            return {"access_token": access_token, 'expires_in': ttl, 'local': True}
+            return {"access_token": access_token.decode('utf-8'), 'expires_in': ttl, 'local': True}
         param = {
-            'appid': self.config.getRaw("weichaet", 'app_id'),
-            'secret': self.config.getRaw("weichaet", 'secret'),
+            'appid': Config.getIns().get("xj_user", 'app_id'),
+            'secret': Config.getIns().get("xj_user", 'secret'),
             'grant_type': 'client_credential'
         }
         response = requests.get(self.wx_token_url, param).json()
         if 'access_token' in response.keys():
-            print(response['access_token'])
             self.redis.set('access_token', response['access_token'])
             self.redis.expire('access_token', response['expires_in'])
         return response
